@@ -1,5 +1,6 @@
 from enum import IntEnum, IntFlag, auto
 from typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     Dict,
@@ -12,6 +13,10 @@ from typing import (
     overload,
 )
 
+if TYPE_CHECKING:
+    from pydantic.annotated_handlers import GetCoreSchemaHandler
+    from pydantic_core import core_schema
+
 __all__ = ["KeyCode", "KeyMod", "ScanCode", "KeyChord"]
 
 # TODO:
@@ -167,6 +172,14 @@ class KeyCode(IntEnum):
     def __get_validators__(cls) -> Generator[Callable[..., 'KeyCode'], None, None]:
         yield cls.validate
 
+    @classmethod
+    def __get_pydantic_core_schema__(
+        cls, source: type, handler: 'GetCoreSchemaHandler'
+    ) -> 'core_schema.CoreSchema':
+        from pydantic_core import core_schema
+
+        return core_schema.no_info_plain_validator_function(cls.validate)
+
     @classmethod
     def validate(cls, value: Any) -> 'KeyCode':
         if isinstance(value, KeyCode):
@@ -183,8 +196,16 @@ class ScanCode(IntEnum):
 
     https://en.wikipedia.org/wiki/Scancode
 
-    These are the scan codea required to conform to the W3C specification for
+    These are the scan codes required to conform to the W3C specification for
     KeyboardEvent.code
+    
+    A scan code is a hardware-specific code that is generated by the keyboard when a key
+    is pressed or released. It represents the physical location of a key on the keyboard
+    and is unique to each key. A key code, on the other hand, is a higher-level
+    representation of a keypress or key release event. They are associated with
+    characters, functions, or actions rather than hardware locations.
+    As an example, the left and right control keys have the same key code (KeyCode.Ctrl)
+    but different scan codes (LeftControl and RightControl).
 
     https://w3c.github.io/uievents-code/
 
@@ -544,7 +565,11 @@ def _build_maps() -> Tuple[
     SCANCODE_FROM_LOWERCASE_STRING: Dict[str, ScanCode] = {}
 
     KEYCODE_TO_STRING: Dict[KeyCode, str] = {}
-    KEYCODE_FROM_LOWERCASE_STRING: Dict[str, KeyCode] = {}
+    KEYCODE_FROM_LOWERCASE_STRING: Dict[str, KeyCode] = {
+        # two special cases for assigning os-specific strings to the meta key
+        'win': KeyCode.Meta,
+        'cmd': KeyCode.Meta,
+    }
 
     seen_scancodes: Set[ScanCode] = set()
     seen_keycodes: Set[KeyCode] = set()
@@ -677,6 +702,13 @@ class KeyChord(int):
 
     It could be two [`KeyCombo`][app_model.types.KeyCombo]
     [`KeyCode`][app_model.types.KeyCode], or [int][].
+
+    Parameters
+    ----------
+    first_part : KeyCombo | int
+        The first part of the chord.
+    second_part : KeyCombo | int
+        The second part of the chord.
     """
 
     def __new__(cls: Type["KeyChord"], first_part: int, second_part: int) -> "KeyChord":
